*******************************
  The :mod:`htsql.tr` package
*******************************

.. automodule:: htsql.tr
   :members:
.. automodule:: htsql.tr.assemble
   :members:
.. automodule:: htsql.tr.bind
   :members:
.. automodule:: htsql.tr.binding
   :members:
.. automodule:: htsql.tr.code
   :members:
.. automodule:: htsql.tr.coerce
   :members:
.. automodule:: htsql.tr.compile
   :members:
.. automodule:: htsql.tr.dump
   :members:
.. automodule:: htsql.tr.encode
   :members:
.. automodule:: htsql.tr.error
   :members:
.. automodule:: htsql.tr.frame
   :members:
.. automodule:: htsql.tr.lookup
   :members:
.. automodule:: htsql.tr.parse
   :members:
.. automodule:: htsql.tr.plan
   :members:
.. automodule:: htsql.tr.reduce
   :members:
.. automodule:: htsql.tr.scan
   :members:
.. automodule:: htsql.tr.signature
   :members:
.. automodule:: htsql.tr.syntax
   :members:
.. automodule:: htsql.tr.term
   :members:
.. automodule:: htsql.tr.token
   :members:

